@@ -182,7 +182,7 @@ def use_config_form_distributed_frame_config_module():
     SQLACHEMY_ENGINE_URL ='sqlite:////sqlachemy_queues/queues.db'
     
     # nb_log包的第几个日志模板，内置了7个模板，可以在你当前项目根目录下的nb_log_config.py文件扩展模板。
-    NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7               
+    NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7  # 7是简短的不可跳转，5是可点击跳转的
     
     \033[0m
     
@@ -219,7 +219,7 @@ def use_config_form_distributed_frame_config_module():
                        
                        SQLACHEMY_ENGINE_URL = 'mysql+pymysql://root:123456@127.0.0.1:3306/sqlachemy_queues?charset=utf8',
                        
-                       NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7,
+                       NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER = 7  # 7是简短的不可跳转，5是可点击跳转的
                        )
 
     show_frame_config()
@@ -258,6 +258,8 @@ def auto_creat_config_file_to_project_root_path():
     if Path(sys.path[1]).as_posix() in Path(__file__).parent.parent.absolute().as_posix():
         nb_print('不希望在本项目里面创建')
         return
+    if '/lib/python' in sys.path[1] or r'\lib\python' in sys.path[1] or '.zip' in sys.path[1]:
+        return  # 当没设置pythonpath时候，也不要在 /lib/python36.zip这样的地方创建配置文件。
     with (Path(sys.path[1]) / Path('distributed_frame_config.py')).open(mode='w', encoding='utf8') as f:
         f.write(config_file_content)
 
