@@ -120,7 +120,7 @@ class MongoBulkWriteHelper(BaseBulkHelper):
                     pass
                     break
             if request_list:
-                print(request_list)
+                # print(request_list)
                 self.base_object.bulk_write(request_list, ordered=False)
             if self._is_print_log:
                 mongo_col_str = re.sub(r"document_class=dict, tz_aware=False, connect=True\),", "", str(self.base_object))
